import React, { useState, useEffect, useRef } from "react";
import "./style.css";
import ChatBoxMessages from "./ChatMessages.js";

const LoginBoxProps = (props) => {
  const { visible, messages, updateMessages, login, updateLogin, user, updateUser } = props.props;
  const [inputValue, setInputValue] = useState("");
  const backendUrl = '/api';
  const [first, setFirst] = useState(true);

useEffect(() => {
    if (first){
      let msg2 = { name: "Janet", message: "What's your name?"};
      updateMessages(msg2);
      setFirst((first) => false);
    }
  }, [first]);


  function handleKeyDown(event) {
    if (event.key === "Enter") {
      onSend(inputValue);
    }
  }

  function onSend(text) {
    if (inputValue === "") {
      return;
    }
    let msg2 = {name: "User", message: inputValue};
    updateMessages(msg2)
    fetch(backendUrl + '/dm', {
      method: 'POST',
      body: JSON.stringify({ username: inputValue }),
      mode: 'cors',
      headers: {
        'Content-Type': 'application/json'
      },
    })
    .then(r => r.json())
    .then(r => {
      let msg3 = { name: "Janet", message: r.answer};
      updateMessages(msg3);
      updateLogin(false);
      updateUser(r.assignedname);
    }).catch((error) => {
      console.error('Error:', error);
      let msg4 = { name: "Janet", message: "Server is down, try later."};
      updateMessages(msg4);
    });
  }

  function handleInputChange(event) {
    setInputValue(event.target.value);
  }

  return (
    <div
      className="chatbox__support"
      style={{
        ...{ opacity: visible ? "1" : "0" },
        ...{ zIndex: visible ? "123456" : "-123456" },
        ...{
          transform: visible ? "translateY(-40px)" : "translateY(0px)"
        }
      }}
    >
      <div className="chatbox__header">
        <div className="chatbox__image--header">
          <img
            src="https://img.icons8.com/color/48/000000/circled-user-female-skin-type-5--v1.png"
            alt=""
          />
        </div>
        <div className="chatbox__content--header">
          <h4 className="chatbox__heading--header">Janet</h4>
          <p className="chatbox__description--header">
            Hi, it's Janet. I am here to help you in utilizing the VRE.
          </p>
        </div>
      </div>
      <ChatBoxMessages messages={messages} />
      <div className="chatbox__footer">
        <input
          type="text"
          placeholder="Write a message..."
          value={inputValue}
          onChange={handleInputChange}
          onKeyDown={handleKeyDown}
        />
        <button className="chatbox__send--footer send__button" onClick={onSend}>
          Send
        </button>
      </div>
    </div>
  );
};

export default LoginBoxProps;

